@@ -87,7 +87,7 @@ def func_time(f):
         return result
     return wrapper
 
-def get_async_result(async_r):
+def create_async_event(async_r):
     new_loop = asyncio.new_event_loop()
     asyncio.set_event_loop(new_loop)
     # new_loop.run_forever()
@@ -97,6 +97,19 @@ def get_async_result(async_r):
 
     return result
 
+def get_async_result(async_r):
+    loop = asyncio.get_event_loop()
+    task = loop.create_task(async_r)
+    # loop.run_until_complete(task)
+    # return task.result
+
+def get_async_result_sql(async_r):
+    loop = asyncio.get_event_loop()
+    task = loop.create_task(async_r)
+    loop.run_until_complete(task)
+    return task.result()
+
+
 
 def get_db_index(db_config_dict):
     return db_config_dict['user'] + '@' + db_config_dict['host'] + ':' + db_config_dict['database']
